@@ -1,10 +1,10 @@
 #ifndef INTER_H
 #define INTER_H
 
-extern "C" {
+// extern "C" {
 #include <R.h>
 #include <Rdefines.h>
-}
+// }
 
 #include "tntsupp.h"
 #include "geese.h"
