@@ -1,7 +1,7 @@
 #ifndef TNTSUPP_H
 #define TNTSUPP_H
 
-using namespace std;
+//using namespace std;
 
 #include <iostream>
 #include "tnt/subscript.h"
@@ -257,7 +257,7 @@ inline Fortran_Matrix<T> operator*(const Region2D<Fortran_Matrix<T> > &A,
     Subscript M = A.num_rows();
     Subscript N = A.num_cols();
 
-    Subscript MN = M*N; 
+// unused    Subscript MN = M*N; 
 
     Fortran_Matrix<T> res(M,N);
     const T* a = A.begin();
