@@ -1,13 +1,11 @@
-using namespace std;
+//using namespace std;
 
 #include "tntsupp.h"
 #include "geese.h"
 
-extern "C"{
 #include <R.h>
 #include <Rmath.h>
 #include <Rdefines.h>
-}
 
 #include "famstr.h"
 #include "param.h"
@@ -104,34 +102,6 @@ SEXP asSEXP(const IVector &a) {
   return val;
 }
 
-SEXP asSEXP(const Vector<DVector> &a) { 
-  // convert a VDVector to a matrix
-  int nrow = a.size(), ncol = a(1).size();
-  int size = nrow * ncol;
-
-  SEXP val;
-  PROTECT(val = NEW_NUMERIC(size));
-  double *p = NUMERIC_POINTER(val);
-
-  int k = 0;
-  for (int i = 1; i <= a.size(); i++) {
-    for (int j = 1; j <= a(i).size(); j++) {
-      p[k++] = a(i)(j);
-    }
-  }
-
-  //  SET_CLASS(val, ScalarString(mkChar("matrix")));
-
-  SEXP dim;
-  PROTECT(dim = NEW_INTEGER(2));
-  INTEGER(dim)[0] = ncol; INTEGER(dim)[1] = nrow;
-  SET_DIM(val, dim);
-
-  UNPROTECT(2);
-  return val;
-}
-
-
 
 Control asControl(SEXP con) {
   //con is a list of trace, jack, j1s, fij, maxiter, epsilon
@@ -159,15 +129,47 @@ GeeParam asGeeParam(SEXP par) {
 GeeStr asGeeStr(SEXP geestr) {
   //geestr is a list of maxwave, meanlink, v, scalelink, corrlink, scale.fix;
   int maxwave = INTEGER(AS_INTEGER(VECTOR_ELT(geestr, 0)))[0];
-  IVector MeanLink = asIVector(AS_INTEGER(VECTOR_ELT(geestr, 1)));
-  IVector V = asIVector(AS_INTEGER(VECTOR_ELT(geestr, 2)));
-  IVector ScaleLink = asIVector(AS_INTEGER(VECTOR_ELT(geestr, 3)));
+  IVector MeanLink, V, ScaleLink;
+
+  // FIXME: rchk gives warning here ...
+  //MeanLink   = asIVector(AS_INTEGER(VECTOR_ELT(geestr, 1)));
+  //V          = asIVector(AS_INTEGER(VECTOR_ELT(geestr, 2)));
+  //ScaleLink  = asIVector(AS_INTEGER(VECTOR_ELT(geestr, 3)));
+  // and to here
+
+  // Attempted fix
+  SEXP ML, VV, SL;
+  PROTECT(ML = AS_INTEGER(VECTOR_ELT(geestr, 1)));
+  PROTECT(VV = AS_INTEGER(VECTOR_ELT(geestr, 2)));
+  PROTECT(SL = AS_INTEGER(VECTOR_ELT(geestr, 3)));
+  MeanLink  = asIVector(ML);
+  V         = asIVector(VV);
+  ScaleLink = asIVector(SL);
+  // to here
+  
   int corrlink = INTEGER(AS_INTEGER(VECTOR_ELT(geestr, 4)))[0];
   int scalefix = INTEGER(AS_INTEGER(VECTOR_ELT(geestr, 5)))[0];
   GeeStr G(maxwave, MeanLink, V, ScaleLink, corrlink, scalefix);
+  UNPROTECT(3);
+  
   return G;
 }
 
+
+
+
+// GeeStr asGeeStr(SEXP geestr) {
+//   //geestr is a list of maxwave, meanlink, v, scalelink, corrlink, scale.fix;
+//   int maxwave = INTEGER(AS_INTEGER(VECTOR_ELT(geestr, 0)))[0];
+//   IVector MeanLink = asIVector(AS_INTEGER(VECTOR_ELT(geestr, 1)));
+//   IVector V = asIVector(AS_INTEGER(VECTOR_ELT(geestr, 2)));
+//   IVector ScaleLink = asIVector(AS_INTEGER(VECTOR_ELT(geestr, 3)));
+//   int corrlink = INTEGER(AS_INTEGER(VECTOR_ELT(geestr, 4)))[0];
+//   int scalefix = INTEGER(AS_INTEGER(VECTOR_ELT(geestr, 5)))[0];
+//   GeeStr G(maxwave, MeanLink, V, ScaleLink, corrlink, scalefix);
+//   return G;
+// }
+
 Corr asCorr(SEXP cor) {
   //cor is a list of corst, maxwave
   int corstr, maxwave;
